@@ -6,10 +6,16 @@ use interoptopus::Interop;
 fn generate_bindings(output: &str) -> Result<(), Error> {
     use interoptopus_backend_c::{Config, Generator};
 
-    Generator::new(Config::default(), interoptopus_reference_project::ffi_inventory()).write_file(output)
+    let config = Config {
+        prefix: "my_library_".to_string(),
+        ..Config::default()
+    };
+
+    Generator::new(config, interoptopus_reference_project::ffi_inventory()).write_file(output)
 }
 
 #[test]
+#[cfg_attr(miri, ignore)]
 fn bindings_match_reference() -> Result<(), Error> {
     generate_bindings("tests/output/my_header.h")?;
 
@@ -19,6 +25,7 @@ fn bindings_match_reference() -> Result<(), Error> {
 }
 
 #[test]
+#[cfg_attr(miri, ignore)]
 fn bindings_work() -> Result<(), Error> {
     generate_bindings("tests/output/my_header.h")?;
     compile_c_app_if_installed("tests/output/", "tests/output/app.c")?;
