@@ -3,5 +3,5 @@
 #include "my_header.h"
 
 int main(int argc, char *argv[]) {
-    printf("C worked.\n");
+    printf("C compiled.\n");
 }
\ No newline at end of file
